@@ -437,7 +437,7 @@ void AptProtocol::get ( const KURL& url )
     for (QueryOptions::ConstIterator i = options.begin(); i != options.end(); ++i)
       m_query.addQueryItem(i.key(), i.data());
 
-    kdDebug() << "Old url " << url << ", new url " << m_query << endl;
+    kdDebug(7130) << "Old url " << url << ", new url " << m_query << endl;
 
     if (m_query != url)
     {
@@ -830,7 +830,7 @@ void AptProtocol::adept_batch(const TQString& query, const QueryOptions& options
       ip = SlaveBase::messageBox(QuestionYesNo,i18n("Do you want to remove the following %1 packages ?\n").arg(pcount).arg(options["package"]));
   }
 
-  kdDebug(DEBUG_ZONE) << command << endl;
+  kdDebug(7130) << command << endl;
 
   if (ip == KMessageBox::Yes)
   {
@@ -934,7 +934,7 @@ extern "C" {
     TDEInstance instance( "tdeio_apt" );
 
     if ( argc != 4 ) {
-      kdDebug( DEBUG_ZONE ) << "Usage: tdeio_apt  protocol domain-socket1 domain-socket2" << endl;
+      kdDebug(7130) << "Usage: tdeio_apt  protocol domain-socket1 domain-socket2" << endl;
       exit ( -1 );
     }
 
